==> HyRiM_1.0.0.tar.gz: HyRiM/R/print.summary.mosg.lossdistribution.R <==
print.summary.mosg.lossdistribution <-
function(x, ...) {
## The all-in-one include header for the HyRiM R package
#
# Authors:         Sandra König, sandra.koenig@ait.ac.at 
#                  Stefan Rass, stefan.rass@aau.at  
#
# Copyright (C) 2014-2017 AIT Austrian Institute of Technology
# AIT Austrian Institute of Technology GmbH
# Donau-City-Strasse 1 | 1220 Vienna | Austria
# http://www.ait.ac.at
#
# This file is part of the AIT HyRiM R Package.
# The AIT HyRiM R Package can be used for non-commercial and 
# academic as well as evaluation purposes. For further information on 
# commercial use, please contact the authors!
# 
# The AIT HyRiM R Package is free software: you can redistribute
# it and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# The AIT HyRiM R Package is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the AIT HyRiM R Package.
# If not, see <http://www.gnu.org/licenses/>.
#
   cat("\n\tloss distribution for multiobjective security game (MOSG)\n\n")
  if (x$is.discrete) {
    cat("type: categorical\n")
  }
  else {
    cat("type: continuous\n")
  }
  cat(paste("loss range:", x$range[1], "to", x$range[2], "\n"))
  cat(paste("mean:", x$mean, "\n"))
  cat(paste("variance:", x$variance, "\n"))
  cat("quantiles:\n")
  print(x$quantiles, ...)
}

==> HyRiM_2.0.1.tar.gz: HyRiM/R/print.summary.mosg.lossdistribution.R <==
print.summary.mosg.lossdistribution <-
function(x, ...) {
## The all-in-one include header for the HyRiM R package
#
# Authors:         Sandra König, sandra.koenig@ait.ac.at 
#                  Stefan Rass, stefan.rass@aau.at  
#
# Copyright (C) 2014-2020 AIT Austrian Institute of Technology
# AIT Austrian Institute of Technology GmbH
# Giefinggasse 4 | 1210 Vienna | Austria
# http://www.ait.ac.at
#
# This file is part of the AIT HyRiM R Package.
# The AIT HyRiM R Package can be used for non-commercial and 
# academic as well as evaluation purposes. For further information on 
# commercial use, please contact the authors!
# 
# The AIT HyRiM R Package is free software: you can redistribute
# it and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 3 of
# the License, or (at your option) any later version.
#
# The AIT HyRiM R Package is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the AIT HyRiM R Package.
# If not, see <http://www.gnu.org/licenses/>.
#
   cat("\n\tloss distribution for multiobjective security game (MOSG)\n\n")
  if (x$is.discrete) {
    cat("type: categorical\n")
  }
  else {
    cat("type: continuous\n")
  }
  cat(paste("loss range:", x$range[1], "to", x$range[2], "\n"))
  cat(paste("mean:", x$mean, "\n"))
  cat(paste("variance:", x$variance, "\n"))
  cat("quantiles:\n")
  print(x$quantiles, ...)
}
